@@ -5,7 +5,9 @@ from quickbooks.objects.term import Term
 
 class TermTests(unittest.TestCase):
     def test_unicode(self):
-        deposit = Term()
-        deposit.Name = "test"
+        term = Term()
+        term.Name = "test"
+
+        self.assertEquals(unicode(term), "test")
+
 
-        self.assertEquals(unicode(deposit), "test")
